is_empty

Function is_empty 

pub(crate) fn is_empty(This: This<Arc<String>>) -> bool
A method on a string type. When added to the CEL context, this function can be called by running. We use the [This] extractor give us a reference to the string that this method was called on.

"foo".isEmpty()