pub(crate) fn fail(ftx: &FunctionContext<'_>) -> ResolveResultExpand description
A function that gives us access to the [FunctionContext]. All functions have
can accept this context as their first argument. The context is helpful for
several reasons:
- Creating shadowed variables using cloned contexts (see the
filterandmapfunctions for example). - Functions that are fallible can return an error message using ftx.error(…) which attaches some helpful context for the error.