pub(crate) fn primitives(
_a: i64,
_b: u64,
_c: f64,
_d: bool,
_e: Arc<String>,
_f: Arc<Vec<u8>>,
_g: Duration,
_h: DateTime<FixedOffset>,
_i: Arc<Vec<Value>>,
) -> DurationExpand description
A function that illustrates all the different types of values that are supported as arguments to a function, as well as the fact that any of these types can also be returned from a function.